<?php
add_filter( 'ocdi/plugin_intro_text', 'kaneshon_ocdi_intro_text' );
/**
 * Adds a link to download the Kaneshon sample content on the OCDI plugin intro page.
 *
 * @param string $html The original intro text.
 * @return string The intro text with the appended sample content link.
 */
function kaneshon_ocdi_intro_text( $html ) {
	$sample_content_url = 'https://www.cssigniter.com/docs/kaneshon/#sample-content';

	ob_start();
	?>
	<div class="notice notice-info"><p><?php
		/* translators: %s is a url. */
		echo wp_kses_post( sprintf( __( 'Looking for the Kaneshon sample content files? Download them <a href="%s" target="_blank">here</a>.', 'kaneshon' ), esc_url( $sample_content_url ) ) );
	?></p></div>
	<hr>
	<?php

	$append_html = ob_get_clean();

	return $html . $append_html;
}

add_action( 'ocdi/after_import', 'kaneshon_ocdi_after_import_setup' );
/**
 * Sets up the theme after importing the demo content.
 *
 * This function assigns the front page and the posts page (blog page) after
 * importing the demo content. It updates the 'show_on_front' option to 'page'
 * and sets the 'page_on_front' option to the ID of the front page, and the
 * 'page_for_posts' option to the ID of the blog page.
 */
function kaneshon_ocdi_after_import_setup() {

	// Assign front page and posts page (blog page).
	$front_page_id = get_page_by_title( 'Home' );
	$blog_page_id  = get_page_by_title( 'Journal' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );
}
